# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .provider_link_response_state import ProviderLinkResponseState
import typing
from .provider_mfa_request import ProviderMfaRequest
from .password_providers import PasswordProviders
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProviderLinkResponse(UniversalBaseModel):
    state: ProviderLinkResponseState
    redirect_url: typing.Optional[str] = None
    error_type: typing.Optional[str] = None
    error: typing.Optional[str] = None
    provider_mfa: typing.Optional[ProviderMfaRequest] = None
    provider: PasswordProviders
    connected: bool
    provider_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .environment import VitalEnvironment
import httpx
from .core.client_wrapper import SyncClientWrapper
from .link.client import LinkClient
from .electrocardiogram.client import ElectrocardiogramClient
from .sleep_cycle.client import SleepCycleClient
from .profile.client import ProfileClient
from .devices.client import DevicesClient
from .activity.client import ActivityClient
from .workouts.client import WorkoutsClient
from .sleep.client import SleepClient
from .body.client import BodyClient
from .meal.client import MealClient
from .menstrual_cycle.client import MenstrualCycleClient
from .vitals.client import VitalsClient
from .user.client import UserClient
from .team.client import TeamClient
from .providers.client import ProvidersClient
from .introspect.client import IntrospectClient
from .lab_tests.client import LabTestsClient
from .testkit.client import TestkitClient
from .order.client import OrderClient
from .insurance.client import InsuranceClient
from .aggregate.client import AggregateClient
from .core.client_wrapper import AsyncClientWrapper
from .link.client import AsyncLinkClient
from .electrocardiogram.client import AsyncElectrocardiogramClient
from .sleep_cycle.client import AsyncSleepCycleClient
from .profile.client import AsyncProfileClient
from .devices.client import AsyncDevicesClient
from .activity.client import AsyncActivityClient
from .workouts.client import AsyncWorkoutsClient
from .sleep.client import AsyncSleepClient
from .body.client import AsyncBodyClient
from .meal.client import AsyncMealClient
from .menstrual_cycle.client import AsyncMenstrualCycleClient
from .vitals.client import AsyncVitalsClient
from .user.client import AsyncUserClient
from .team.client import AsyncTeamClient
from .providers.client import AsyncProvidersClient
from .introspect.client import AsyncIntrospectClient
from .lab_tests.client import AsyncLabTestsClient
from .testkit.client import AsyncTestkitClient
from .order.client import AsyncOrderClient
from .insurance.client import AsyncInsuranceClient
from .aggregate.client import AsyncAggregateClient


class Vital:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : VitalEnvironment
        The environment to use for requests from the client. from .environment import VitalEnvironment



        Defaults to VitalEnvironment.PRODUCTION



    api_key : str
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from vital import Vital

    client = Vital(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: VitalEnvironment = VitalEnvironment.PRODUCTION,
        api_key: str,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.link = LinkClient(client_wrapper=self._client_wrapper)
        self.electrocardiogram = ElectrocardiogramClient(client_wrapper=self._client_wrapper)
        self.sleep_cycle = SleepCycleClient(client_wrapper=self._client_wrapper)
        self.profile = ProfileClient(client_wrapper=self._client_wrapper)
        self.devices = DevicesClient(client_wrapper=self._client_wrapper)
        self.activity = ActivityClient(client_wrapper=self._client_wrapper)
        self.workouts = WorkoutsClient(client_wrapper=self._client_wrapper)
        self.sleep = SleepClient(client_wrapper=self._client_wrapper)
        self.body = BodyClient(client_wrapper=self._client_wrapper)
        self.meal = MealClient(client_wrapper=self._client_wrapper)
        self.menstrual_cycle = MenstrualCycleClient(client_wrapper=self._client_wrapper)
        self.vitals = VitalsClient(client_wrapper=self._client_wrapper)
        self.user = UserClient(client_wrapper=self._client_wrapper)
        self.team = TeamClient(client_wrapper=self._client_wrapper)
        self.providers = ProvidersClient(client_wrapper=self._client_wrapper)
        self.introspect = IntrospectClient(client_wrapper=self._client_wrapper)
        self.lab_tests = LabTestsClient(client_wrapper=self._client_wrapper)
        self.testkit = TestkitClient(client_wrapper=self._client_wrapper)
        self.order = OrderClient(client_wrapper=self._client_wrapper)
        self.insurance = InsuranceClient(client_wrapper=self._client_wrapper)
        self.aggregate = AggregateClient(client_wrapper=self._client_wrapper)


class AsyncVital:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : VitalEnvironment
        The environment to use for requests from the client. from .environment import VitalEnvironment



        Defaults to VitalEnvironment.PRODUCTION



    api_key : str
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from vital import AsyncVital

    client = AsyncVital(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: VitalEnvironment = VitalEnvironment.PRODUCTION,
        api_key: str,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.link = AsyncLinkClient(client_wrapper=self._client_wrapper)
        self.electrocardiogram = AsyncElectrocardiogramClient(client_wrapper=self._client_wrapper)
        self.sleep_cycle = AsyncSleepCycleClient(client_wrapper=self._client_wrapper)
        self.profile = AsyncProfileClient(client_wrapper=self._client_wrapper)
        self.devices = AsyncDevicesClient(client_wrapper=self._client_wrapper)
        self.activity = AsyncActivityClient(client_wrapper=self._client_wrapper)
        self.workouts = AsyncWorkoutsClient(client_wrapper=self._client_wrapper)
        self.sleep = AsyncSleepClient(client_wrapper=self._client_wrapper)
        self.body = AsyncBodyClient(client_wrapper=self._client_wrapper)
        self.meal = AsyncMealClient(client_wrapper=self._client_wrapper)
        self.menstrual_cycle = AsyncMenstrualCycleClient(client_wrapper=self._client_wrapper)
        self.vitals = AsyncVitalsClient(client_wrapper=self._client_wrapper)
        self.user = AsyncUserClient(client_wrapper=self._client_wrapper)
        self.team = AsyncTeamClient(client_wrapper=self._client_wrapper)
        self.providers = AsyncProvidersClient(client_wrapper=self._client_wrapper)
        self.introspect = AsyncIntrospectClient(client_wrapper=self._client_wrapper)
        self.lab_tests = AsyncLabTestsClient(client_wrapper=self._client_wrapper)
        self.testkit = AsyncTestkitClient(client_wrapper=self._client_wrapper)
        self.order = AsyncOrderClient(client_wrapper=self._client_wrapper)
        self.insurance = AsyncInsuranceClient(client_wrapper=self._client_wrapper)
        self.aggregate = AsyncAggregateClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: VitalEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import datetime as dt
import typing
from .client_facing_electrocardiogram_classification import ClientFacingElectrocardiogramClassification
from .client_facing_electrocardiogram_inconclusive_cause import ClientFacingElectrocardiogramInconclusiveCause
from .client_facing_electrocardiogram_source_provider import ClientFacingElectrocardiogramSourceProvider
from .client_facing_electrocardiogram_source_type import ClientFacingElectrocardiogramSourceType
from .client_facing_source import ClientFacingSource
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ClientFacingElectrocardiogram(UniversalBaseModel):
    id: str
    session_start: dt.datetime
    session_end: dt.datetime
    voltage_sample_count: int
    heart_rate_mean: typing.Optional[int] = None
    sampling_frequency_hz: typing.Optional[float] = None
    classification: typing.Optional[ClientFacingElectrocardiogramClassification] = None
    inconclusive_cause: typing.Optional[ClientFacingElectrocardiogramInconclusiveCause] = None
    algorithm_version: typing.Optional[str] = None
    time_zone: typing.Optional[str] = None
    source_provider: ClientFacingElectrocardiogramSourceProvider
    source_type: ClientFacingElectrocardiogramSourceType
    source_app_id: typing.Optional[str] = None
    source_device_model: typing.Optional[str] = None
    user_id: str
    source: ClientFacingSource

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .fats import Fats
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class Macros(UniversalBaseModel):
    carbs: typing.Optional[float] = pydantic.Field(default=None)
    """
    Amount of carbohydrates in grams (g)
    """

    protein: typing.Optional[float] = pydantic.Field(default=None)
    """
    Amount of protein in grams (g)
    """

    fats: typing.Optional[Fats] = pydantic.Field(default=None)
    """
    Details of fat content
    """

    alcohol: typing.Optional[float] = pydantic.Field(default=None)
    """
    Amount of alcohol in grams (g)
    """

    water: typing.Optional[float] = pydantic.Field(default=None)
    """
    Amount of water in grams (g)
    """

    fibre: typing.Optional[float] = pydantic.Field(default=None)
    """
    Amount of dietary fiber in grams (g)
    """

    sugar: typing.Optional[float] = pydantic.Field(default=None)
    """
    Amount of sugar in grams (g)
    """

    cholesterol: typing.Optional[float] = pydantic.Field(default=None)
    """
    Amount of cholesterol in grams (g)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class IndexColumnExprIndex(str, enum.Enum):
    SLEEP = "sleep"
    ACTIVITY = "activity"
    WORKOUT = "workout"
    BODY = "body"
    MEAL = "meal"

    def visit(
        self,
        sleep: typing.Callable[[], T_Result],
        activity: typing.Callable[[], T_Result],
        workout: typing.Callable[[], T_Result],
        body: typing.Callable[[], T_Result],
        meal: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is IndexColumnExprIndex.SLEEP:
            return sleep()
        if self is IndexColumnExprIndex.ACTIVITY:
            return activity()
        if self is IndexColumnExprIndex.WORKOUT:
            return workout()
        if self is IndexColumnExprIndex.BODY:
            return body()
        if self is IndexColumnExprIndex.MEAL:
            return meal()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestsGetRequestOrderDirection(str, enum.Enum):
    ASC = "asc"
    DESC = "desc"

    def visit(self, asc: typing.Callable[[], T_Result], desc: typing.Callable[[], T_Result]) -> T_Result:
        if self is LabTestsGetRequestOrderDirection.ASC:
            return asc()
        if self is LabTestsGetRequestOrderDirection.DESC:
            return desc()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingNoteSampleTagsItem(str, enum.Enum):
    FOOD = "food"
    EXERCISE = "exercise"
    INSULIN_INJECTION = "insulin_injection"
    UNSPECIFIED = "unspecified"

    def visit(
        self,
        food: typing.Callable[[], T_Result],
        exercise: typing.Callable[[], T_Result],
        insulin_injection: typing.Callable[[], T_Result],
        unspecified: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingNoteSampleTagsItem.FOOD:
            return food()
        if self is ClientFacingNoteSampleTagsItem.EXERCISE:
            return exercise()
        if self is ClientFacingNoteSampleTagsItem.INSULIN_INJECTION:
            return insulin_injection()
        if self is ClientFacingNoteSampleTagsItem.UNSPECIFIED:
            return unspecified()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .client_facing_provider import ClientFacingProvider
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class ConnectedSourceClientFacing(UniversalBaseModel):
    provider: ClientFacingProvider = pydantic.Field()
    """
    The provider of this connected source.
    """

    created_on: str = pydantic.Field()
    """
    When your item is created
    """

    source: ClientFacingProvider = pydantic.Field()
    """
    Deprecated. Use `provider` instead. Subject to removal after 1 Jan 2024.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class WorkoutColumnExprWorkout(str, enum.Enum):
    SESSION_START = "session_start"
    SESSION_END = "session_end"
    TITLE = "title"
    SPORT_NAME = "sport_name"
    SPORT_SLUG = "sport_slug"
    DURATION_ACTIVE_SECOND = "duration_active_second"
    HEART_RATE_MEAN = "heart_rate_mean"
    HEART_RATE_MINIMUM = "heart_rate_minimum"
    HEART_RATE_MAXIMUM = "heart_rate_maximum"
    HEART_RATE_ZONE_1 = "heart_rate_zone_1"
    HEART_RATE_ZONE_2 = "heart_rate_zone_2"
    HEART_RATE_ZONE_3 = "heart_rate_zone_3"
    HEART_RATE_ZONE_4 = "heart_rate_zone_4"
    HEART_RATE_ZONE_5 = "heart_rate_zone_5"
    HEART_RATE_ZONE_6 = "heart_rate_zone_6"
    DISTANCE_METER = "distance_meter"
    CALORIES = "calories"
    ELEVATION_GAIN_METER = "elevation_gain_meter"
    ELEVATION_MAXIMUM_METER = "elevation_maximum_meter"
    ELEVATION_MINIMUM_METER = "elevation_minimum_meter"
    SPEED_MEAN = "speed_mean"
    SPEED_MAXIMUM = "speed_maximum"
    POWER_SOURCE = "power_source"
    POWER_MEAN = "power_mean"
    POWER_MAXIMUM = "power_maximum"
    POWER_WEIGHTED_MEAN = "power_weighted_mean"
    STEPS = "steps"
    MAP_POLYLINE = "map_polyline"
    MAP_SUMMARY_POLYLINE = "map_summary_polyline"
    SOURCE_TYPE = "source_type"
    SOURCE_PROVIDER = "source_provider"
    SOURCE_APP_ID = "source_app_id"
    SOURCE_WORKOUT_ID = "source_workout_id"
    TIME_ZONE = "time_zone"

    def visit(
        self,
        session_start: typing.Callable[[], T_Result],
        session_end: typing.Callable[[], T_Result],
        title: typing.Callable[[], T_Result],
        sport_name: typing.Callable[[], T_Result],
        sport_slug: typing.Callable[[], T_Result],
        duration_active_second: typing.Callable[[], T_Result],
        heart_rate_mean: typing.Callable[[], T_Result],
        heart_rate_minimum: typing.Callable[[], T_Result],
        heart_rate_maximum: typing.Callable[[], T_Result],
        heart_rate_zone_1: typing.Callable[[], T_Result],
        heart_rate_zone_2: typing.Callable[[], T_Result],
        heart_rate_zone_3: typing.Callable[[], T_Result],
        heart_rate_zone_4: typing.Callable[[], T_Result],
        heart_rate_zone_5: typing.Callable[[], T_Result],
        heart_rate_zone_6: typing.Callable[[], T_Result],
        distance_meter: typing.Callable[[], T_Result],
        calories: typing.Callable[[], T_Result],
        elevation_gain_meter: typing.Callable[[], T_Result],
        elevation_maximum_meter: typing.Callable[[], T_Result],
        elevation_minimum_meter: typing.Callable[[], T_Result],
        speed_mean: typing.Callable[[], T_Result],
        speed_maximum: typing.Callable[[], T_Result],
        power_source: typing.Callable[[], T_Result],
        power_mean: typing.Callable[[], T_Result],
        power_maximum: typing.Callable[[], T_Result],
        power_weighted_mean: typing.Callable[[], T_Result],
        steps: typing.Callable[[], T_Result],
        map_polyline: typing.Callable[[], T_Result],
        map_summary_polyline: typing.Callable[[], T_Result],
        source_type: typing.Callable[[], T_Result],
        source_provider: typing.Callable[[], T_Result],
        source_app_id: typing.Callable[[], T_Result],
        source_workout_id: typing.Callable[[], T_Result],
        time_zone: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is WorkoutColumnExprWorkout.SESSION_START:
            return session_start()
        if self is WorkoutColumnExprWorkout.SESSION_END:
            return session_end()
        if self is WorkoutColumnExprWorkout.TITLE:
            return title()
        if self is WorkoutColumnExprWorkout.SPORT_NAME:
            return sport_name()
        if self is WorkoutColumnExprWorkout.SPORT_SLUG:
            return sport_slug()
        if self is WorkoutColumnExprWorkout.DURATION_ACTIVE_SECOND:
            return duration_active_second()
        if self is WorkoutColumnExprWorkout.HEART_RATE_MEAN:
            return heart_rate_mean()
        if self is WorkoutColumnExprWorkout.HEART_RATE_MINIMUM:
            return heart_rate_minimum()
        if self is WorkoutColumnExprWorkout.HEART_RATE_MAXIMUM:
            return heart_rate_maximum()
        if self is WorkoutColumnExprWorkout.HEART_RATE_ZONE_1:
            return heart_rate_zone_1()
        if self is WorkoutColumnExprWorkout.HEART_RATE_ZONE_2:
            return heart_rate_zone_2()
        if self is WorkoutColumnExprWorkout.HEART_RATE_ZONE_3:
            return heart_rate_zone_3()
        if self is WorkoutColumnExprWorkout.HEART_RATE_ZONE_4:
            return heart_rate_zone_4()
        if self is WorkoutColumnExprWorkout.HEART_RATE_ZONE_5:
            return heart_rate_zone_5()
        if self is WorkoutColumnExprWorkout.HEART_RATE_ZONE_6:
            return heart_rate_zone_6()
        if self is WorkoutColumnExprWorkout.DISTANCE_METER:
            return distance_meter()
        if self is WorkoutColumnExprWorkout.CALORIES:
            return calories()
        if self is WorkoutColumnExprWorkout.ELEVATION_GAIN_METER:
            return elevation_gain_meter()
        if self is WorkoutColumnExprWorkout.ELEVATION_MAXIMUM_METER:
            return elevation_maximum_meter()
        if self is WorkoutColumnExprWorkout.ELEVATION_MINIMUM_METER:
            return elevation_minimum_meter()
        if self is WorkoutColumnExprWorkout.SPEED_MEAN:
            return speed_mean()
        if self is WorkoutColumnExprWorkout.SPEED_MAXIMUM:
            return speed_maximum()
        if self is WorkoutColumnExprWorkout.POWER_SOURCE:
            return power_source()
        if self is WorkoutColumnExprWorkout.POWER_MEAN:
            return power_mean()
        if self is WorkoutColumnExprWorkout.POWER_MAXIMUM:
            return power_maximum()
        if self is WorkoutColumnExprWorkout.POWER_WEIGHTED_MEAN:
            return power_weighted_mean()
        if self is WorkoutColumnExprWorkout.STEPS:
            return steps()
        if self is WorkoutColumnExprWorkout.MAP_POLYLINE:
            return map_polyline()
        if self is WorkoutColumnExprWorkout.MAP_SUMMARY_POLYLINE:
            return map_summary_polyline()
        if self is WorkoutColumnExprWorkout.SOURCE_TYPE:
            return source_type()
        if self is WorkoutColumnExprWorkout.SOURCE_PROVIDER:
            return source_provider()
        if self is WorkoutColumnExprWorkout.SOURCE_APP_ID:
            return source_app_id()
        if self is WorkoutColumnExprWorkout.SOURCE_WORKOUT_ID:
            return source_workout_id()
        if self is WorkoutColumnExprWorkout.TIME_ZONE:
            return time_zone()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ActivityColumnExprActivity(str, enum.Enum):
    DATE = "date"
    CALORIES_TOTAL = "calories_total"
    CALORIES_ACTIVE = "calories_active"
    STEPS = "steps"
    DISTANCE_METER = "distance_meter"
    FLOORS_CLIMBED = "floors_climbed"
    DURATION_ACTIVE_SECOND = "duration_active_second"
    INTENSITY_SEDENTARY_SECOND = "intensity_sedentary_second"
    INTENSITY_LOW_SECOND = "intensity_low_second"
    INTENSITY_MEDIUM_SECOND = "intensity_medium_second"
    INTENSITY_HIGH_SECOND = "intensity_high_second"
    HEART_RATE_MEAN = "heart_rate_mean"
    HEART_RATE_MINIMUM = "heart_rate_minimum"
    HEART_RATE_MAXIMUM = "heart_rate_maximum"
    HEART_RATE_RESTING = "heart_rate_resting"
    SOURCE_TYPE = "source_type"
    SOURCE_PROVIDER = "source_provider"
    SOURCE_APP_ID = "source_app_id"
    TIME_ZONE = "time_zone"
    TIME_ZONE_OFFSET = "time_zone_offset"

    def visit(
        self,
        date: typing.Callable[[], T_Result],
        calories_total: typing.Callable[[], T_Result],
        calories_active: typing.Callable[[], T_Result],
        steps: typing.Callable[[], T_Result],
        distance_meter: typing.Callable[[], T_Result],
        floors_climbed: typing.Callable[[], T_Result],
        duration_active_second: typing.Callable[[], T_Result],
        intensity_sedentary_second: typing.Callable[[], T_Result],
        intensity_low_second: typing.Callable[[], T_Result],
        intensity_medium_second: typing.Callable[[], T_Result],
        intensity_high_second: typing.Callable[[], T_Result],
        heart_rate_mean: typing.Callable[[], T_Result],
        heart_rate_minimum: typing.Callable[[], T_Result],
        heart_rate_maximum: typing.Callable[[], T_Result],
        heart_rate_resting: typing.Callable[[], T_Result],
        source_type: typing.Callable[[], T_Result],
        source_provider: typing.Callable[[], T_Result],
        source_app_id: typing.Callable[[], T_Result],
        time_zone: typing.Callable[[], T_Result],
        time_zone_offset: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ActivityColumnExprActivity.DATE:
            return date()
        if self is ActivityColumnExprActivity.CALORIES_TOTAL:
            return calories_total()
        if self is ActivityColumnExprActivity.CALORIES_ACTIVE:
            return calories_active()
        if self is ActivityColumnExprActivity.STEPS:
            return steps()
        if self is ActivityColumnExprActivity.DISTANCE_METER:
            return distance_meter()
        if self is ActivityColumnExprActivity.FLOORS_CLIMBED:
            return floors_climbed()
        if self is ActivityColumnExprActivity.DURATION_ACTIVE_SECOND:
            return duration_active_second()
        if self is ActivityColumnExprActivity.INTENSITY_SEDENTARY_SECOND:
            return intensity_sedentary_second()
        if self is ActivityColumnExprActivity.INTENSITY_LOW_SECOND:
            return intensity_low_second()
        if self is ActivityColumnExprActivity.INTENSITY_MEDIUM_SECOND:
            return intensity_medium_second()
        if self is ActivityColumnExprActivity.INTENSITY_HIGH_SECOND:
            return intensity_high_second()
        if self is ActivityColumnExprActivity.HEART_RATE_MEAN:
            return heart_rate_mean()
        if self is ActivityColumnExprActivity.HEART_RATE_MINIMUM:
            return heart_rate_minimum()
        if self is ActivityColumnExprActivity.HEART_RATE_MAXIMUM:
            return heart_rate_maximum()
        if self is ActivityColumnExprActivity.HEART_RATE_RESTING:
            return heart_rate_resting()
        if self is ActivityColumnExprActivity.SOURCE_TYPE:
            return source_type()
        if self is ActivityColumnExprActivity.SOURCE_PROVIDER:
            return source_provider()
        if self is ActivityColumnExprActivity.SOURCE_APP_ID:
            return source_app_id()
        if self is ActivityColumnExprActivity.TIME_ZONE:
            return time_zone()
        if self is ActivityColumnExprActivity.TIME_ZONE_OFFSET:
            return time_zone_offset()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingElectrocardiogramClassification(str, enum.Enum):
    SINUS_RHYTHM = "sinus_rhythm"
    ATRIAL_FIBRILLATION = "atrial_fibrillation"
    INCONCLUSIVE = "inconclusive"

    def visit(
        self,
        sinus_rhythm: typing.Callable[[], T_Result],
        atrial_fibrillation: typing.Callable[[], T_Result],
        inconclusive: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingElectrocardiogramClassification.SINUS_RHYTHM:
            return sinus_rhythm()
        if self is ClientFacingElectrocardiogramClassification.ATRIAL_FIBRILLATION:
            return atrial_fibrillation()
        if self is ClientFacingElectrocardiogramClassification.INCONCLUSIVE:
            return inconclusive()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ManualProviders(str, enum.Enum):
    BEURER_BLE = "beurer_ble"
    OMRON_BLE = "omron_ble"
    ACCUCHEK_BLE = "accuchek_ble"
    CONTOUR_BLE = "contour_ble"
    FREESTYLE_LIBRE_BLE = "freestyle_libre_ble"
    ONETOUCH_BLE = "onetouch_ble"
    APPLE_HEALTH_KIT = "apple_health_kit"
    MANUAL = "manual"
    HEALTH_CONNECT = "health_connect"

    def visit(
        self,
        beurer_ble: typing.Callable[[], T_Result],
        omron_ble: typing.Callable[[], T_Result],
        accuchek_ble: typing.Callable[[], T_Result],
        contour_ble: typing.Callable[[], T_Result],
        freestyle_libre_ble: typing.Callable[[], T_Result],
        onetouch_ble: typing.Callable[[], T_Result],
        apple_health_kit: typing.Callable[[], T_Result],
        manual: typing.Callable[[], T_Result],
        health_connect: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ManualProviders.BEURER_BLE:
            return beurer_ble()
        if self is ManualProviders.OMRON_BLE:
            return omron_ble()
        if self is ManualProviders.ACCUCHEK_BLE:
            return accuchek_ble()
        if self is ManualProviders.CONTOUR_BLE:
            return contour_ble()
        if self is ManualProviders.FREESTYLE_LIBRE_BLE:
            return freestyle_libre_ble()
        if self is ManualProviders.ONETOUCH_BLE:
            return onetouch_ble()
        if self is ManualProviders.APPLE_HEALTH_KIT:
            return apple_health_kit()
        if self is ManualProviders.MANUAL:
            return manual()
        if self is ManualProviders.HEALTH_CONNECT:
            return health_connect()



# This file was auto-generated by Fern from our API Definition.

import typing
from .sleep_column_expr import SleepColumnExpr
from .activity_column_expr import ActivityColumnExpr
from .workout_column_expr import WorkoutColumnExpr
from .body_column_expr import BodyColumnExpr
from .index_column_expr import IndexColumnExpr
from .sleep_score_value_macro_expr import SleepScoreValueMacroExpr
from .chronotype_value_macro_expr import ChronotypeValueMacroExpr
from .unrecognized_value_macro_expr import UnrecognizedValueMacroExpr

AggregateExprArg = typing.Union[
    SleepColumnExpr,
    ActivityColumnExpr,
    WorkoutColumnExpr,
    BodyColumnExpr,
    IndexColumnExpr,
    SleepScoreValueMacroExpr,
    ChronotypeValueMacroExpr,
    UnrecognizedValueMacroExpr,
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingHeartRateAlertSampleType(str, enum.Enum):
    LOW_HEART_RATE = "low_heart_rate"
    HIGH_HEART_RATE = "high_heart_rate"
    IRREGULAR_RHYTHM = "irregular_rhythm"

    def visit(
        self,
        low_heart_rate: typing.Callable[[], T_Result],
        high_heart_rate: typing.Callable[[], T_Result],
        irregular_rhythm: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingHeartRateAlertSampleType.LOW_HEART_RATE:
            return low_heart_rate()
        if self is ClientFacingHeartRateAlertSampleType.HIGH_HEART_RATE:
            return high_heart_rate()
        if self is ClientFacingHeartRateAlertSampleType.IRREGULAR_RHYTHM:
            return irregular_rhythm()



# This file was auto-generated by Fern from our API Definition.

import enum


class VitalEnvironment(enum.Enum):
    PRODUCTION = "https://api.tryvital.io"
    PRODUCTION_EU = "https://api.eu.tryvital.io"
    SANDBOX = "https://api.sandbox.tryvital.io"
    SANDBOX_EU = "https://api.sandbox.eu.tryvital.io"



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestCollectionMethod(str, enum.Enum):
    """
    The method used to perform a lab test.
    """

    TESTKIT = "testkit"
    WALK_IN_TEST = "walk_in_test"
    AT_HOME_PHLEBOTOMY = "at_home_phlebotomy"

    def visit(
        self,
        testkit: typing.Callable[[], T_Result],
        walk_in_test: typing.Callable[[], T_Result],
        at_home_phlebotomy: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestCollectionMethod.TESTKIT:
            return testkit()
        if self is LabTestCollectionMethod.WALK_IN_TEST:
            return walk_in_test()
        if self is LabTestCollectionMethod.AT_HOME_PHLEBOTOMY:
            return at_home_phlebotomy()
